using System;
using Terraria.ModLoader;
using Terraria;
using System.IO;


// TODO: Change 'GameModeLoader' to the name of your mod's unique namespace
namespace ExampleGameModeLoader {
	static class GameModeInfo {
		// TODO: Change this to set the human readable name of your game mode/custom world set
		public static string Name { get { return "My Custom Game Mode"; } }
		// TODO: Change this to set the prefix string for game mode commands (no spaces or punctuations)
		public static string Command { get { return "mygame"; } }
		// TODO: Define a comma-separated list of world files packaged with this game mode (the .wld and .twld files must be packaged with the mod)
		public static string[] WorldNames { get { return new string[] { "Johnsonsonville" }; } }
		// TODO: Define a comma-separated list of player files packaged for this game mode (the .plr and .tplr files must be packaged with the mod)
		public static string[] PlayerNames { get { return new string[] { "Johnsonson" }; } }
	}



	// TODO: Change this to the name of your game mode (e.g. ArcticSurvivalGameModeLoaderMod)
	class ExampleGameModeLoaderMod : Mod {
		public static Mod Instance { get; private set; }

		// TODO: Update these accordingly, also (or just remove these lines, if not applicable)
		public static string GithubUserName { get { return "hamstar0"; } }
		public static string GithubProjectName { get { return "tml-examplegamemodeloadertemplate-mod"; } }



		////////////////

		public ExampleGameModeLoaderMod() {
			this.Properties = new ModProperties() {
				Autoload = true,
				AutoloadGores = true,
				AutoloadSounds = true
			};
		}

		////////////////

		public override void Load() {
			ExampleGameModeLoaderMod.Instance = this;

			this.LoadGameMode();
		}

		public override void Unload() {
			ExampleGameModeLoaderMod.Instance = null;
		}


		////////////////

		public void LoadGameMode() {
			foreach( string world in GameModeInfo.WorldNames ) {
				this.LoadWorld( world );
			}
			foreach( string plr in GameModeInfo.PlayerNames ) {
				this.LoadPlayer( plr );
			}
		}


		public void ClearGameMode() {
			foreach( string world in GameModeInfo.WorldNames ) {
				this.ClearWorld( world );
			}
			foreach( string plr in GameModeInfo.PlayerNames ) {
				this.ClearPlayer( plr );
			}
		}


		////////////////

		private void LoadWorld( string world_name ) {
			if( !this.File.HasFile(world_name+".wld") ) {
				throw new Exception( "Game mode loader is missing world file for " + world_name);
			}

			string world_path = Main.SavePath + Path.DirectorySeparatorChar + "Worlds" + Path.DirectorySeparatorChar;
			string full_wld_file_path = world_path + world_name + ".wld";

			if( !System.IO.File.Exists( full_wld_file_path ) ) {
				byte[] wld_data = this.File.GetFile( world_name + ".wld" );

				System.IO.File.WriteAllBytes( full_wld_file_path, wld_data );
				
				if( this.File.HasFile( world_name+".twld" ) ) {
					string full_twld_file_path = world_path + world_name + ".twld";
					byte[] twld_data = this.File.GetFile( world_name + ".twld" );

					System.IO.File.WriteAllBytes( full_twld_file_path, twld_data );
				}
			}
		}

		private void LoadPlayer( string player_name ) {
			if( !this.File.HasFile( player_name + ".plr" ) ) {
				throw new Exception( "Game mode loader is missing player file for " + player_name );
			}

			string player_path = Main.SavePath + Path.DirectorySeparatorChar + "Players" + Path.DirectorySeparatorChar;
			string full_plr_file_path = player_path + player_name + ".plr";

			if( !System.IO.File.Exists( full_plr_file_path ) ) {
				byte[] wld_data = this.File.GetFile( player_name + ".plr" );

				System.IO.File.WriteAllBytes( full_plr_file_path, wld_data );

				if( this.File.HasFile( player_name + ".tplr" ) ) {
					string full_tplr_file_path = player_path + player_name + ".tplr";
					byte[] twld_data = this.File.GetFile( player_name + ".tplr" );

					System.IO.File.WriteAllBytes( full_tplr_file_path, twld_data );
				}
			}
		}

		////////////////


		private void ClearWorld( string world_name ) {
			string world_path = Main.SavePath + Path.DirectorySeparatorChar + "Worlds" + Path.DirectorySeparatorChar;
			string full_wld_file_path = world_path + world_name + ".wld";
			string full_twld_file_path = world_path + world_name + ".twld";

			if( System.IO.File.Exists( full_wld_file_path ) ) {
				System.IO.File.Delete( full_wld_file_path );
			}
			if( System.IO.File.Exists( full_twld_file_path ) ) {
				System.IO.File.Delete( full_twld_file_path );
			}
		}

		private void ClearPlayer( string player_name ) {
			string player_path = Main.SavePath + Path.DirectorySeparatorChar + "Players" + Path.DirectorySeparatorChar;
			string full_plr_file_path = player_path + player_name + ".plr";
			string full_tplr_file_path = player_path + player_name + ".tplr";

			if( System.IO.File.Exists( full_plr_file_path ) ) {
				System.IO.File.Delete( full_plr_file_path );
			}
			if( System.IO.File.Exists( full_tplr_file_path ) ) {
				System.IO.File.Delete( full_tplr_file_path );
			}
		}
	}
}
